# MERCI: Model Evaluation of Reliability for Classifier Inference - reliability analysis of classifiers in Python

## Introduction

PyPI: https://pypi.org/project/merci/
...

## Installation

To install MERCI for local development, clone the repository and install with pip:

```bash
git clone <repo_url>
cd merci
pip install -e .
```

For a basic installation, use:

```bash
pip install merci
```
